methods

package
v0.0.0-...-60f7d2f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 27, 2020 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConvTimeFormat

func ConvTimeFormat(strTime string, timeFormat int) (string, error)

ConvTimeFormat ...

func GetPath

func GetPath(path string) string

GetPath returns the path to the main working directory (if path = "") or the path to the file inside the application, if it's path is specified.

func LocDate

func LocDate(timezone string) (string, error)

LocDate ...

func LocTime

func LocTime(timezone string) (string, error)

LocTime ...

func LocWeekday

func LocWeekday(timezone string) (string, error)

LocWeekday ...

func TimeZoneGPS

func TimeZoneGPS(Longitude, Latitude float64, timeformat int) (loctime string, tz string)

TimeZoneGPS ...

func TimeZoneManually

func TimeZoneManually(strtz string, timeformat int) (loctime string, tz string, err error)

TimeZoneManually ...

Types

This section is empty.

Jump to